# Kinematics-PyTorch
WIP Project. Codes are subject to change anytime.

## Installation

```
pip install kpt
```

## Quick Start


## To Do

* Update README

## Test

```bash
pytest
```


## Reference

```
@inproceedings{pavllo:quaternet:2018,
  title={QuaterNet: A Quaternion-based Recurrent Model for Human Motion},
  author={Pavllo, Dario and Grangier, David and Auli, Michael},
  booktitle={British Machine Vision Conference (BMVC)},
  year={2018}
}
```